==> payara-embedded-all-5.2020.4-sources.jar: com/sun/enterprise/security/auth/realm/RealmsManagerStore.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2013 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
// Portions Copyright [2018-2019] Payara Foundation and/or affiliates
package com.sun.enterprise.security.auth.realm;

import java.lang.ref.WeakReference;

import org.glassfish.internal.api.Globals;

/**
 * This class stores a static, but weak, reference to the realms manager.
 * 
 * @see RealmsManager
 * 
 * @author Arjan Tijms (factored out from Realm)
 *
 */
public class RealmsManagerStore {

    private static WeakReference<RealmsManager> realmsManager = new WeakReference<RealmsManager>(null);

    static RealmsManager tryGetRealmsManager() {
        RealmsManager manager = getRealmsManager();
        if (manager == null) {
            throw new RuntimeException("Unable to locate RealmsManager Service");
        }

        return manager;
    }

    static RealmsManager getRealmsManager() {
        if (realmsManager.get() != null) {
            return realmsManager.get();
        }

        return _getRealmsManager();
    }

    static synchronized RealmsManager _getRealmsManager() {
        if (realmsManager.get() == null) {
            if (Globals.getDefaultHabitat() != null) {
                realmsManager = new WeakReference<RealmsManager>(Globals.get(RealmsManager.class));
            } else {
                return null;
            }
        }

        return realmsManager.get();
    }

}

==> payara-embedded-all-6.2023.4-sources.jar: com/sun/enterprise/security/auth/realm/RealmsManagerStore.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2013 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
// Portions Copyright [2018-2019] Payara Foundation and/or affiliates
package com.sun.enterprise.security.auth.realm;

import java.lang.ref.WeakReference;

import org.glassfish.internal.api.Globals;

/**
 * This class stores a static, but weak, reference to the realms manager.
 * 
 * @see RealmsManager
 * 
 * @author Arjan Tijms (factored out from Realm)
 *
 */
public class RealmsManagerStore {

    private static WeakReference<RealmsManager> realmsManager = new WeakReference<RealmsManager>(null);

    static RealmsManager tryGetRealmsManager() {
        RealmsManager manager = getRealmsManager();
        if (manager == null) {
            throw new RuntimeException("Unable to locate RealmsManager Service");
        }

        return manager;
    }

    static RealmsManager getRealmsManager() {
        if (realmsManager.get() != null) {
            return realmsManager.get();
        }

        return _getRealmsManager();
    }

    static synchronized RealmsManager _getRealmsManager() {
        if (realmsManager.get() == null) {
            if (Globals.getDefaultHabitat() != null) {
                realmsManager = new WeakReference<>(Globals.get(RealmsManager.class));
            } else {
                return null;
            }
        }

        return realmsManager.get();
    }

}
